AmberPrepParser — biskit 3.0.0a1 documentation

# AmberPrepParser

class `biskit.` `AmberPrepParser`(f_in=None)

  Bases: `object`

  Parse Amber Residue libraries (off or prep files) which are usually found in amber/dat/leap/prep.

  Usage:

      p = AmberOffParser( 'all_amino03.in' )
      residues = [ r for r in p.residueTypes() ]

  Returns AmberResidue instances that can be handled like a PDBModel although the xyz array contains relative Z-coordinates not real cartesian ones. Atom profiles of the AmberResidue instance include:

  > - charge … atomic partial charge (float)
  > - name … atom name (str)
  > - amber_type … Amber atom type (str)

  Methods Overview

  `__init__` |
  param f_in: | amber “off” or “prep” file with residue definitions if not existing, we will look for a file with this name in the Biskit data folder (data/amber/residues) (default: ‘all_amino03.in’) :type f_in: str
  `atomLines` |
  param s: | str, atom block
  `createResidue` |
  `parseCharges` |
  `parseResidue` |
  param s: | str, residue record
  `residueBlocks` |
  `residueDict` |
  return: | dict, residue types indexed by 3-letter residue code, example: {‘ala’:[AmberResidueType ALA], ‘cys’:[…}
  `residueTypes` |

  Attributes Overview

  `F_DEFAULT` |

  ## AmberPrepParser Method & Attribute Details

  `__init__`(f_in=None)

    Parameters: | f_in (str) – amber “off” or “prep” file with residue definitions if not existing, we will look for a file with this name in the Biskit data folder (data/amber/residues) (default: ‘all_amino03.in’)

  `atomLines`(s)

    Parameters: | s – str, atom block

  `parseResidue`(s)

    Parameters: | s – str, residue record

  `createResidue`(res, atoms)
  `residueDict`()

    Returns: | dict, residue types indexed by 3-letter residue code, example: {‘ala’:[AmberResidueType ALA], ‘cys’:[…}